# AiiDA-Scheduler
[![PyPI version](https://badge.fury.io/py/aiida-scheduler.svg)](https://badge.fury.io/py/aiida-scheduler)
[![Unit test](https://github.com/superstar54/aiida-scheduler/actions/workflows/ci.yaml/badge.svg)](https://github.com/superstar54/aiida-scheduler/actions/workflows/ci.yaml)
[![codecov](https://codecov.io/gh/superstar54/aiida-scheduler/branch/main/graph/badge.svg)](https://codecov.io/gh/superstar54/aiida-scheduler)
[![Docs status](https://readthedocs.org/projects/aiida-scheduler/badge)](http://aiida-scheduler.readthedocs.io/)

Efficiently control the execution of AiiDA processes with AiiDA Scheduler:
* enforce dynamic concurrency limits per HPC allocation;
* implement priority scheduling so urgent workflows start first; and
* obtain live visibility into queue state and utilisation in a GUI.

## Installation

```console
    pip install aiida-scheduler
```


## Documentation
Explore the comprehensive [documentation](https://aiida-scheduler.readthedocs.io/en/latest/) to discover all the features and capabilities of AiiDA Scheduler.


## License
[MIT](http://opensource.org/licenses/MIT)
